import 'dart:convert';
import 'package:flutter/material.dart';
import 'package:url_launcher/url_launcher.dart';
import 'package:onairos/onairos_utils.dart'; // Ensure you import the utility class correctly

class OnairosButton extends StatelessWidget {
  final Map<String, Map<String, String>> requestData;
  final String returnLink;
  // Hard-coded path to the Onairos logo within your package's assets
  final String logoAssetPath = 'images/onairos_logo.png'; // Ensure this path is valid in your package

  const OnairosButton({
    super.key,
    required this.requestData,
    required this.returnLink,
  });


  Future<void> _openOnairosOverlay(BuildContext context) async {
    String jsonString = jsonEncode(requestData);
    String encodedData = Uri.encodeComponent(jsonString);

    // Use the utility class to build the Uri
    var url = OnairosUtils.buildOnairosUri(encodedData, returnLink);

    try {
      if (await canLaunchUrl(url)) {
        await launchUrl(url);
      } else {
        // Handle the case where the URL cannot be launched
        showErrorModal(context, 'Could not launch $url');
      }
    } catch (e) {
      // Handle any other exceptions that might occur
      showErrorModal(context, 'An error occurred: $e');
      throw 'Could not launch $url';
    }
  }

  void showErrorModal(BuildContext context, String errorMessage) {
    showDialog(
      context: context,
      builder: (context) {
        return AlertDialog(
          title: const Text('Error'),
          content: Text(errorMessage),
          actions: [
            TextButton(
              onPressed: () => Navigator.of(context).pop(),
              child: const Text('OK'),
            ),
          ],
        );
      },
    );
  }

  @override
  Widget build(BuildContext context) {
    return ElevatedButton(
      // onPressed: _openOnairosOverlay(context),
      onPressed: () => _openOnairosOverlay(context),
      child: Image.asset(logoAssetPath), // Use the hard-coded asset path
      style: ElevatedButton.styleFrom(
        foregroundColor: Colors.grey, backgroundColor: Colors.white, shape: const CircleBorder(),
        padding: const EdgeInsets.all(10), // Splash color
      ),
    );
  }
}
