import 'dart:convert';
import 'package:flutter/material.dart';
import 'package:url_launcher/url_launcher.dart';
import 'package:onairos/onairos_utils.dart'; // Ensure you import the utility class correctly


class OnairosButtonWrapper extends StatefulWidget {
  final Map<String, Map<String, String>> requestData;
  final String returnLink;

  const OnairosButtonWrapper({
    Key? key,
    required this.requestData,
    required this.returnLink,
  }) : super(key: key);

  @override
  _OnairosButtonWrapperState createState() => _OnairosButtonWrapperState();
}

class _OnairosButtonWrapperState extends State<OnairosButtonWrapper> {
  Future<void> _openOnairosOverlay(BuildContext context) async {
    String jsonString = jsonEncode(widget.requestData);
    String encodedData = Uri.encodeComponent(jsonString);

    // Use the utility class to build the Uri
    var url = OnairosUtils.buildOnairosUri(encodedData, widget.returnLink);

    try {
      if (await canLaunchUrl(url)) {
        await launchUrl(url);
      } else {
        // Handle the case where the URL cannot be launched
        showErrorModal(context, 'Could not launch $url');
      }
    } catch (e) {
      // Handle any other exceptions that might occur
      showErrorModal(context, 'An error occurred: $e');
      throw 'Could not launch $url';
    }
  }

  void showErrorModal(BuildContext context, String errorMessage) {
    if (mounted) {
      showDialog(
        context: context,
        builder: (context) {
          return AlertDialog(
            title: Text('Error'),
            content: Text(errorMessage),
            actions: [
              TextButton(
                onPressed: () => Navigator.of(context).pop(),
                child: Text('OK'),
              ),
            ],
          );
        },
      );
    }
  }

  @override
  Widget build(BuildContext context) {
    return OnairosButton(
      requestData: widget.requestData,
      returnLink: widget.returnLink,
      openOnairosOverlay: _openOnairosOverlay,
    );
  }
}


class OnairosButton extends StatelessWidget {
  final Map<String, Map<String, String>> requestData;
  final String returnLink;
  final Future<void> Function(BuildContext context) openOnairosOverlay;

  const OnairosButton({
    Key? key,
    required this.requestData,
    required this.returnLink,
    required this.openOnairosOverlay,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return ElevatedButton(
      onPressed: () => openOnairosOverlay(context),
      child: Image.asset('images/onairos_logo.png'),
      style: ElevatedButton.styleFrom(
        foregroundColor: Colors.grey,
        backgroundColor: Colors.white,
        shape: CircleBorder(),
        padding: EdgeInsets.all(10),
      ),
    );
  }
}